Release Notes for Trac 1.4 'Jinja' Release
===========================================
August 28, 2019

Highlights
----------
* Jinja2 templating engine
* Custom navigation items for main and meta navigation
* TracAdmin command for converting databases
* Restyled wiki

Detailed User Visible Changes
-----------------------------

A detailed view of the changes since 1.2.x can be found in
https://trac.edgewall.org/wiki/TracDev/ReleaseNotes/1.4

Developer-visible changes
-------------------------

A detailed view of the API changes since 1.2.x can be found in
https://trac.edgewall.org/wiki/TracDev/ApiChanges/1.4

Acknowledgements
----------------

Many thanks to the growing number of people who have, and continue to,
support the project. Also our thanks to all people providing feedback
and bug reports that helps us making Trac better, easier to use and
more effective. Starting with the 0.12 release, special thanks go to
our many translators.  Without your invaluable help, Trac would not
evolve. Thank you all.

Finally, we hope that Trac will prove itself useful to like-minded
programmers around the world, and that this release will prove an
improvement over the last version.

Please let us know. :-)

/The Trac Team https://trac.edgewall.org/
